@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include "knetstatsview.h"
 #include "knetstats.h"
@@ -64,7 +64,7 @@ extern "C" {
 extern const char* programName;
 
 KNetStatsView::KNetStatsView(KNetStats* parent, const QString& interface)
-: KSystemTray(parent, 0), mSysDevPath("/sys/class/net/"+interface+"/"), mInterface(interface) {
+: KSystemTray(parent, 0), mSysDevPath("/sys/class/net/"+interface+'/'), mInterface(interface) {
 	mFdSock = 0;
 	mFirstUpdate = true;
 	mMaxSpeedAge = 0;
